@@ -13,8 +13,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef JUK_TAGRENAMEROPTIONS_H
-#define JUK_TAGRENAMEROPTIONS_H
+#ifndef TAGRENAMEROPTIONS_H
+#define TAGRENAMEROPTIONS_H
+
+#include <QtCore/QString>
 
 // Insert all new tag types before NumTypes, that way NumTypes will always be
 // the count of valid tag types.
@@ -127,14 +129,11 @@ public:
     }
 
     /**
-     * Function that tries to match a string back to its category.  Uses
-     * the case-sensitive form of the string.  If it fails it will return
-     * Unknown.
-     *
-     * @param translated If true, @p text is translated, if false, it is the untranslated
-     *                   version.
+     * Function that tries to match a string back to its category.  Uses only
+     * the untranslated and case-sensitive form of the string.  If it fails it
+     * will return Unknown.
      */
-    static TagType tagFromCategoryText(const QString &text, bool translate = true);
+    static TagType tagFromCategoryText(const QString &text);
 
     /**
      * This saves the options to the global KConfig object.
@@ -171,6 +170,6 @@ private:
     TagType m_category;
 };
 
-#endif /* JUK_TAGRENAMEROPTIONS_H */
+#endif /* TAGRENAMEROPTIONS_H */
 
-// vim: set et ts=4 sw=4:
+// vim: set et sw=4 tw=0 sta:
